===========================================
Citation, Acknowledgments, and Contributors
===========================================


Citation
=================================
If you use this software in a publication, please cite the software

..  code-block:: bibtex

    @software{fastml_hls4ml,
    author       = {{FastML Team}},
    title        = {fastmachinelearning/hls4ml},
    year         = 2024,
    publisher    = {Zenodo},
    version      = {v1.0.0},
    doi          = {10.5281/zenodo.1201549},
    url          = {https://github.com/fastmachinelearning/hls4ml}
    }

and first publication:

..  code-block:: bibtex

    @article{Duarte:2018ite,
        author = "Duarte, Javier and others",
        title = "{Fast inference of deep neural networks in FPGAs for particle physics}",
        eprint = "1804.06913",
        archivePrefix = "arXiv",
        primaryClass = "physics.ins-det",
        reportNumber = "FERMILAB-PUB-18-089-E",
        doi = "10.1088/1748-0221/13/07/P07027",
        journal = "JINST",
        volume = "13",
        number = "07",
        pages = "P07027",
        year = "2018"
    }

Additionally, if you use specific features developed in later papers, please cite those as well. For example, CNNs:

..  code-block:: bibtex

    @article{Aarrestad:2021zos,
        author = "Aarrestad, Thea and others",
        title = "{Fast convolutional neural networks on FPGAs with hls4ml}",
        eprint = "2101.05108",
        archivePrefix = "arXiv",
        primaryClass = "cs.LG",
        reportNumber = "FERMILAB-PUB-21-130-SCD",
        doi = "10.1088/2632-2153/ac0ea1",
        journal = "Mach. Learn. Sci. Tech.",
        volume = "2",
        number = "4",
        pages = "045015",
        year = "2021"
    }
    @article{Ghielmetti:2022ndm,
        author = "Ghielmetti, Nicol\`{o} and others",
        title = "{Real-time semantic segmentation on FPGAs for autonomous vehicles with hls4ml}",
        eprint = "2205.07690",
        archivePrefix = "arXiv",
        primaryClass = "cs.CV",
        reportNumber = "FERMILAB-PUB-22-435-PPD",
        doi = "10.1088/2632-2153/ac9cb5",
        journal ="Mach. Learn. Sci. Tech.",
        year = "2022"
    }

distributed arithmetic:

..  code-block:: bibtex

    @misc{Sun:2025,
        title={da4ml: Distributed Arithmetic for Real-time Neural Networks on FPGAs},
        author={Chang Sun and others},
        year={2025},
        eprint={2507.04535},
        archivePrefix={arXiv},
        primaryClass={cs.AR},
        url={https://arxiv.org/abs/2507.04535},
    }

binary/ternary networks:

..  code-block:: bibtex

    @article{Loncar:2020hqp,
        author = "Ngadiuba, Jennifer and others",
        title = "{Compressing deep neural networks on FPGAs to binary and ternary precision with HLS4ML}",
        eprint = "2003.06308",
        archivePrefix = "arXiv",
        primaryClass = "cs.LG",
        reportNumber = "FERMILAB-PUB-20-167-PPD-SCD",
        doi = "10.1088/2632-2153/aba042",
        journal = "Mach. Learn. Sci. Tech.",
        volume = "2",
        pages = "015001",
        year = "2021"
    }

optimization API:

..  code-block:: bibtex

    @article{Ramhorst:2023fpga,
      author = "Benjamin Ramhorst and others",
      title = "{FPGA Resource-aware Structured Pruning for Real-Time Neural Networks}",
      eprint = "2308.05170",
      archivePrefix = "arXiv",
      primaryClass = "cs.AR",
      year = "2023"
    }

Acknowledgments
===============
If you benefited from participating in our community, we ask that you please acknowledge the Fast Machine Learning collaboration, and particular individuals who helped you, in any publications.
Please use the following text for this acknowledgment:

  We acknowledge the Fast Machine Learning collective as an open community of multi-domain experts and collaborators. This community and \<names of individuals\>, in particular, were important for the development of this project.


Funding
=======
We gratefully acknowledge previous and current support from the U.S. National Science Foundation (NSF) Harnessing the Data Revolution (HDR) Institute for `Accelerating AI Algorithms for Data Driven Discovery (A3D3) <https://a3d3.ai>`_ under Cooperative Agreement No. `PHY-2117997 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=2117997>`_, U.S. Department of Energy (DOE) Office of Science, Office of Advanced Scientific Computing Research under the Real‐time Data Reduction Codesign at the Extreme Edge for Science (XDR) Project (`DE-FOA-0002501 <https://science.osti.gov/-/media/grants/pdf/foas/2021/SC_FOA_0002501.pdf>`_), DOE Office of Science, Office of High Energy Physics Early Career Research Program (`DE-SC0021187 <https://pamspublic.science.energy.gov/WebPAMSExternal/Interface/Common/ViewPublicAbstract.aspx?rv=df0ae4ab-a46e-481a-9acc-3856b6b041e5&rtc=24&PRoleId=10>`_, DE-0000247070), and the European Research Council (ERC) under the European Union's Horizon 2020 research and innovation program (Grant No. `772369 <https://doi.org/10.3030/772369>`_).

.. image:: https://github.com/fastmachinelearning/hls4ml/assets/29201053/bd1217d4-9930-47b7-8917-ad3fc430c75d
    :height: 130
    :align: center

.. image:: https://github.com/fastmachinelearning/hls4ml/assets/4932543/16e77374-9829-40a8-800e-8d12018a7cb3
    :height: 130
    :align: center

.. image:: https://github.com/fastmachinelearning/hls4ml/assets/4932543/de6ca6ea-4d1c-4c56-9d93-f759914bbbf9
    :height: 130
    :align: center

.. image:: https://github.com/fastmachinelearning/hls4ml/assets/4932543/7a369971-a381-4bb8-932a-7162b173cbac
    :height: 130
    :align: center

Contributors
============

Thanks to our contributors!

..  contributors:: fastmachinelearning/hls4ml
   :avatars:
   :limit: 100
   :order: DESC
